@@ -37,10 +37,10 @@ class VersionProps {
         "openjdk";
 
     private static final String java_version =
-        "14.0.2";
+        "14";
 
     private static final String java_version_date =
-        "2020-07-14";
+        "2020-03-17";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -48,16 +48,16 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "14.0.2+12";
+        "14+36";
 
     private static final String VERSION_NUMBER =
-        "14.0.2";
+        "14";
 
     private static final String VERSION_SPECIFICATION =
         "14";
 
     private static final String VERSION_BUILD =
-        "12";
+        "36";
 
     private static final String VERSION_PRE =
         "";
